#
# spec file for package buildah
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define project github.com/containers/buildah
# Build with libostree-devel in Tumbleweed, Leap 15 and SLES 15
%if 0%{?suse_version} >= 1500
%define with_libostree 1
%endif
Name:           buildah
Version:        1.7.1
Release:        lp151.2.3.1
Summary:        Tool for building OCI containers
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/containers/buildah
Source0:        %{name}-%{version}.tar.xz
Source1:        %{name}-rpmlintrc
Patch0:         CVE-2019-10214.patch
BuildRequires:  bash-completion
BuildRequires:  device-mapper-devel
BuildRequires:  fdupes
BuildRequires:  git
BuildRequires:  glib2-devel-static
BuildRequires:  glibc-devel-static
BuildRequires:  go-go-md2man
BuildRequires:  golang-packaging
BuildRequires:  libapparmor-devel
BuildRequires:  libassuan-devel
BuildRequires:  libbtrfs-devel
BuildRequires:  libgpgme-devel
BuildRequires:  libseccomp-devel
BuildRequires:  golang(API) >= 1.10
Requires:       libcontainers-common
Requires:       libcontainers-image
Requires:       libcontainers-storage
Requires:       runc >= 1.0.0~rc4
Requires:       slirp4netns
%{go_nostrip}
%if 0%{?with_libostree}
BuildRequires:  libostree-devel
%endif

%description
Buildah provides a command line tool which can be used to:
- Create a working container, either from scratch or using an image as a
  starting point
- Create an image, either from a working container or via the instructions in a
  Dockerfile
- Build images in either the OCI image format or the traditional
  upstream docker image format
- Mount a working container's root filesystem for manipulation
- Unmount a working container's root filesystem
- Update the contents of a container's root filesystem
- Delete a working container or an image

%prep
%setup -q
%patch0 -p0

%build
# We can't use symlinks here because go-list gets confused by symlinks, so we
# have to copy the source to $HOME/go and then use that as the GOPATH.
export GOPATH=$HOME/go
mkdir -pv $HOME/go/src/%{project}
rm -rf $HOME/go/src/%{project}/*
cp -avr * $HOME/go/src/%{project}
cd $HOME/go/src/%{project}

%if 0%{?with_libostree}
echo "Compiling with libostree support"
export BUILDTAGS="seccomp apparmor"
%else
echo "Compiling without libostree support"
export BUILDTAGS="seccomp apparmor containers_image_ostree_stub"
%endif

export CNIVersion=`sed -e '\,github.com/containernetworking/cni, !d' -e 's,.* ,,g' vendor.conf`
# Build buildah
go build -tags "$BUILDTAGS" \
         -buildmode=pie \
         -ldflags '-s -w -X main.buildInfo='$SOURCE_DATE_EPOCH' -X main.cniVersion='$CNIVersion'' \
         -o bin/buildah \
         %{project}/cmd/buildah

# Build manpages
make %{?_smp_mflags} -C docs

%check
# Too many tests fail due to the restricted permissions in the build enviroment.
# Updates must be tested manually.

%install
cd $HOME/go/src/%{project}

install -D -m 0755 bin/buildah %{buildroot}/%{_bindir}/buildah
install -d %{buildroot}/%{_mandir}/man1
install -m 0644 docs/buildah*.1 %{buildroot}/%{_mandir}/man1
install -D -m 0644 contrib/completions/bash/buildah %{buildroot}/%{_datadir}/bash-completion/completions/buildah

%fdupes %{buildroot}/%{_prefix}

%files
%{_bindir}/buildah
%{_mandir}/man1/buildah*
%{_datadir}/bash-completion/completions/buildah
%license LICENSE

%changelog
* Mon Sep  2 2019 Sascha Grunert <sgrunert@suse.com>
- Add patch for CVE-2019-10214. bsc#1144065
  + CVE-2019-10214.patch
* Fri Mar  1 2019 Richard Brown <rbrown@suse.com>
- Update to v1.7.1
  * Minor fix to vendor in github.com/containers/image 1.5 version
  * This fixes a crash on pulling of images
- Stop building from specific commit
* Tue Feb 26 2019 Richard Brown <rbrown@suse.com>
- Update to v1.7
  * vendor containers/image v1.4
  * Make "images --all" faster
  * Remove quiet option from pull options
  * Support oci layout format
* Thu Jan 17 2019 Richard Brown <rbrown@suse.com>
- Update to v1.6
  * unshare: do not set USER=root
  * run: ignore EIO when flushing at the end, avoid double log
  * build-using-dockerfile,commit: disable compression by default
  * Make rootless work under no_pivot_root
  * Properly format images JSON output
  * Assume user 0 group 0, if /etc/passwd file in container.
  * Add buildah info command
- Full changelog: https://github.com/containers/buildah/releases/tag/v1.6
* Fri Nov 23 2018 Valentin Rothberg <vrothberg@suse.com>
- Changelog for v1.5-1 (2018-11-21)
  * Print command in SystemExec as debug information
  * Sort CLI flags
  * Update imagebuild depdency to support heading ARGs in Dockerfile
  * rootless: do not specify --rootless to the OCI runtime
  * Exclude --force-rm from common bud cli flags
  * run: bind mount /etc/hosts and /etc/resolv.conf if not in a volume
  * rootless: use slirp4netns to setup the network namespace
  * rootless: only discard network configuration names
  * run: only set up /etc/hosts or /etc/resolv.conf with network
  * Handle directories better in bud -f
  * common: support a per-user registries conf file
  * unshare: do not override the configuration
  * common: honor the rootless configuration file
  * unshare: create a new mount namespace
  * unshare: support libpod rootless pkg
  * Allow container storage to manage the SELinux labels
  * imagebuilder.BuildDockerfiles: return the image ID
  * Allow setting --no-pivot default with an env var
  * Add man page and bash completion, for --no-pivot
  * Add the --no-pivot flag to the run command
  * Improve reporting about individual pull failures
  * Fix From As in Dockerfile
  * Sort CLI flags of buildah bud
  * unshare: detect when unprivileged userns are disabled
  * buildah: use the same logic for XDG_RUNTIME_DIR as podman
  * Make sure we log or return every error
  * Correctly set DockerInsecureSkipTLSVerify when pulling images
  * chroot: set up seccomp and capabilities after supplemental groups
  * chroot: fix capabilities list setup and application
* Sun Nov  4 2018 Valentin Rothberg <vrothberg@suse.com>
- Require slirp4netns to enable networking for unprivileged network namespaces
  aka networking for rootless buildah.
* Wed Oct  3 2018 Valentin Rothberg <vrothberg@suse.com>
- Changelog for v1.4 (2018-10-02)
  * Touchup pull manpage
  * Export buildah ReserveSELinuxLables so podman can use it
  * Update rmi man for prune changes
  * Copy ExposedPorts from base image into the config
  * Change rmi --prune to not accept an imageID
  * Builtin volumes should be owned by the UID/GID of the container
  * Move buildah from projecatatomic/buildah to containers/buildah
  * bash: Completion options
  * Don't build btrfs if it is not installed
  * Push: Allow an empty destination
  * Fix arg usage in buildah-tag
  * Evaluate symbolic links on Add/Copy Commands
  * Retain bounding set when running containers as non root
  * push: show image digest after push succeed
  * Exclude --layers from the common bug cli flags
  * Make buildah-from error message clear when flags are after arg
  * Warn about using Commands in Dockerfile that are not supported by OCI.
  * Document BUILDAH_* environment variables in buildah bud --help output
  * Fix --layers ADD from url issue
  * Display the correct ID after deleting image
  * Handle COPY --chown in Dockerfile
  * Document STORAGE_DRIVER and STORAGE_OPTS environment variable
  * Expand variables names for --env
* Wed Sep  5 2018 Valentin Rothberg <vrothberg@suse.com>
- Set the correct commit for `buildah version`.
- Set the cnilib version for `buildah version`.
* Mon Aug  6 2018 vrothberg@suse.com
- Update buildah to v1.3:
  * bud should not search context directory for Dockerfile
  * Set BUILDAH_ISOLATION=rootless when running unprivileged
  * Fix rmi to remove intermediate images associated with an image
  * Set the default ulimits to match Docker
  * buildah: no args is out of bounds
  * preprocess ".in" suffixed Dockerfiles
  * Add support for multiple Short options
  * Update to latest urvave/cli
  * Create buildah pull command
  * Allow ping command without NET_RAW Capabilities
  * Allow Dockerfile content to come from stdin
  * add rename command
  * Completion command
  * Update vendor for runc to fix 32 bit builds
* Mon Jul 16 2018 vrothberg@suse.com
- Update buildah to v1.2:
  * build-using-dockerfile: let -t include transports again
  * Block use of /proc/acpi and /proc/keys from inside containers
  * Fix handling of -registries-conf
  * Add -cidfile option to from
  * Add a -loglevel option to build-with-dockerfile
  * docs: Follow man-pages(7) suggestions for SYNOPSIS
  * umount: add all option to umount all mounted containers
  * Fix buildah bud -layers
  * Force ownership of /etc/hosts and /etc/resolv.conf to 0:0
  * build without seccomp
  * Add Capabilities lists to BuilderInfo
  * Fix ARGS parsing for run commands
  * Add info on registries.conf to from manpage
  * mount: support multiple inputs
  * Allow -userns-uid-map/-userns-gid-map to be global options
  * Add -rm and -force-rm to buildah bud
  * Add -all,-a flag to buildah images
  * Add environment variable BUILDAH_RUNTIME
  * Add -layers and -no-cache to buildah bud
  * Change 'registries' to 'container registries' in man
  * Add registries.conf link to a few man pages
- install missing buildah (1) manpage
- install bash completion at /usr/share/bash-completion/completions
- buildmode=pie: build position independent code
* Mon Jun 11 2018 vrothberg@suse.com
- Update buildah to v1.1:
  * Drop capabilities if running container processes as non root
  * Print Warning message if cmd will not be used based on entrypoint
  * Shouldn't add insecure registries to list of search registries
  * Report errors on bad transports specification when pushing images
  * Add disable-content-trust noop flag to bud
  * runCopyStdio(): don't close stdin unless we saw POLLHUP
  * Add registry errors for pull
  * Give better messages to users when image can not be found
  * Add environment variable to buildah --format
  * Accept json array input for config entrypoint
  * Add OnBuild support for Dockerfiles
  * buildah bud should require a context directory or URL
  * buildah bud picks up ENV from base image
  * Add CLI options for specifying namespace and cgroup setup
  * Read UID/GID mapping information from containers and images
  * build-using-dockerfile: add --annotation
  * Implement --squash for build-using-dockerfile and commit
  * Vendor in latest container/storage for devicemapper support
  * Test with Go 1.10, too
  * Handle /etc/hosts and /etc/resolv.conf properly in container
  * Add support for buildah bud --label
  * buildah push/from can push and pull images with no reference
  * builder-inspect: fix format option
  * Add cpu-shares short flag (-c) and cpu-shares CI tests
* Sun Jun 10 2018 jengelh@inai.de
- Use noun phrase in summary.
* Thu Jun  7 2018 vrothberg@suse.com
- Update buildah to v1.0:
  * Update option and documentation for --force-rm
  * Update buildah run to make command required
  * Do not print directly to stdout in Commit()
  * Force "localhost" as a default registry
  * Validate host and container paths passed to --volume
  * Add --compress, --rm, --squash flags as a noop for bud
  * Add FIPS mode secret to buildah run and bud
  * Add config --comment/--domainname/--history-comment/--hostname
  * 'buildah config': stop replacing Created-By whenever it's not specified
  * Modify man pages so they compile correctly in mandb
  * Add description on how to do --isolation to buildah-bud man page
  * Add support for --iidfile to bud and commit
  * Remove tarball as an option from buildah push --help
  * Fix secrets patch
  * Display imageId after commit
  * config: add support for StopSignal
  * Allow referencing stages as index and names
  * Add multi-stage builds support
  * Allow umount to have multi-containers
  * buildah bud walks symlinks
  * Allow --cmd parameter to have commands as values
  * Make default-mounts-file a hidden option
  * Add various transport support to buildah from
  * shallowCopy: avoid a second read of the container's layer
  * Add openSUSE in install section
  * run: do not open /etc/hosts if not needed
* Tue Jun  5 2018 dcassany@suse.com
- Refactor %%license usage to a simpler form
* Mon Jun  4 2018 dcassany@suse.com
- Make use of %%license macro
* Wed Apr  4 2018 vrothberg@suse.com
- Change build date to SOURCE_DATE_EPOCH to make builds reproducible.
* Thu Mar 29 2018 vrothberg@suse.com
- Fix `buildah version` by compiling the build date into the binary.
* Tue Mar  6 2018 vrothberg@suse.com
- Package buildah v0.12.  Buildah is a tool to build OCI images, and is used
  by podman-build.
